@@ -3,19 +3,23 @@ from random import choice
 from mpd import MPDClient
 
 class LockableMPDClient(MPDClient):
-    def __init__(self, use_unicode=False):
+    def __init__(self):
         super(LockableMPDClient, self).__init__()
-        self.use_unicode = use_unicode
         self._lock = Lock()
+
     def acquire(self):
         self._lock.acquire()
+
     def release(self):
         self._lock.release()
+
     def __enter__(self):
         self.acquire()
+
     def __exit__(self, type, value, traceback):
         self.release()
 
+
 client = LockableMPDClient()
 client.connect("localhost", 6600)
 # now whenever you need thread-safe access
@@ -38,6 +42,7 @@ def fetch_playlist():
                 playlist = client.playlist()
             assert isinstance(playlist, list)
 
+
 threads = []
 for i in range(5):
     t = Thread(target=fetch_playlist)
